@@ -16,27 +16,28 @@
 #' @export
 #' @name UniprocessFuture-class
 #' @keywords internal
-UniprocessFuture <- function(expr=NULL, envir=parent.frame(), substitute=FALSE, globals=TRUE, lazy=FALSE, local=TRUE, ...) {
+UniprocessFuture <- function(expr = NULL, envir = parent.frame(), substitute = FALSE, globals = TRUE, packages = NULL, lazy = FALSE, local = TRUE, ...) {
   if (substitute) expr <- substitute(expr)
 
   if (lazy) {
     ## Evaluate in a local environment?
     if (local) {
-      envir <- new.env(parent=envir)
+      envir <- new.env(parent = envir)
     } else {
       if (!is.logical(globals) || globals) {
-        stop("Non-supported use of lazy uniprocess futures: Whenever argument 'local' is FALSE, then argument 'globals' must also be FALSE. Lazy uniprocess future evaluation in the calling environment (local=FALSE) can only be done if global objects are resolved at the same time.")
+        stop("Non-supported use of lazy uniprocess futures: Whenever argument 'local' is FALSE, then argument 'globals' must also be FALSE. Lazy uniprocess future evaluation in the calling environment (local = FALSE) can only be done if global objects are resolved at the same time.")
       }
     }
   }
 
   ## Global objects
   assignToTarget <- (is.list(globals) || inherits(globals, "Globals"))
-  gp <- getGlobalsAndPackages(expr, envir=envir, tweak=tweakExpression, globals=globals, resolve=TRUE)
+  gp <- getGlobalsAndPackages(expr, envir = envir, tweak = tweakExpression, globals = globals)
 
-  ## Assign?
-  if (length(gp) > 0 && (lazy || assignToTarget)) {
-    target <- new.env(parent=envir)
+  ## Assign globals to "target" environment?
+  if (length(gp$globals) > 0 && (lazy || assignToTarget)) {
+    target <- new.env(parent = envir)
+    target[["...future_has_globals"]] <- TRUE
     globalsT <- gp$globals
     for (name in names(globalsT)) {
       target[[name]] <- globalsT[[name]]
@@ -44,15 +45,23 @@ UniprocessFuture <- function(expr=NULL, envir=parent.frame(), substitute=FALSE,
     globalsT <- NULL
     envir <- target
   }
+
+  ## Record packages?
+  if (length(packages) > 0 || (length(gp$packages) > 0 && lazy)) {
+    packages <- unique(c(gp$packages, packages))
+  }
+  
   gp <- NULL
 
-  f <- Future(expr=expr, envir=envir, substitute=FALSE, lazy=lazy, asynchronous=FALSE, local=local, ...)
-  structure(f, class=c("UniprocessFuture", class(f)))
+  f <- Future(expr = expr, envir = envir, substitute = FALSE, lazy = lazy, asynchronous = FALSE, local = local, globals = NULL, packages = packages, ...)
+  structure(f, class = c("UniprocessFuture", class(f)))
 }
 
 
 #' @export
 run.UniprocessFuture <- function(future, ...) {
+  debug <- getOption("future.debug", FALSE)
+  
   if (future$state != 'created') {
     stop("A future can only be launched once.")
   }
@@ -75,7 +84,7 @@ run.UniprocessFuture <- function(future, ...) {
   current <- sys.nframe()
   tryCatch({
     withCallingHandlers({
-      future$value <- eval(expr, envir=envir)
+      future$value <- eval(expr, envir = envir)
       future$state <- 'finished'
     }, error = function(ex) {
       calls <- sys.calls()
@@ -83,7 +92,7 @@ run.UniprocessFuture <- function(future, ...) {
       calls <- calls[seq_len(length(calls)-2L)]
       ## Drop fluff added by outer tryCatch()
       calls <- calls[-seq_len(current+7L)]
-      ## Drop fluff added by outer local=TRUE
+      ## Drop fluff added by outer local = TRUE
       if (future$local) calls <- calls[-seq_len(6L)]
       ex$traceback <- calls
       future$value <- ex
@@ -91,9 +100,11 @@ run.UniprocessFuture <- function(future, ...) {
     })
   }, error = function(ex) {})
 
+  if (debug) mdebug("%s started (and completed)", class(future)[1])
+  
   ## Signal conditions early, iff specified for the given future
-  signalEarly(future, collect=FALSE)
-
+  signalEarly(future, collect = FALSE)
+  
   invisible(future)
 }
 
@@ -106,40 +117,24 @@ resolved.UniprocessFuture <- function(x, ...) {
     ## such that the future gets resolved.  The reason for this
     ## is so that polling is always possible, e.g.
     ## while(!resolved(f)) Sys.sleep(5);
-    value(x, signal=FALSE)
+    value(x, signal = FALSE)
   }
   NextMethod("resolved")
 }
 
-
-#' @rdname UniprocessFuture-class
-#' @export
-SequentialFuture <- function(expr=NULL, envir=parent.frame(), substitute=FALSE, lazy=FALSE, globals=TRUE, local=TRUE, ...) {
-  if (substitute) expr <- substitute(expr)
-  f <- UniprocessFuture(expr=expr, envir=envir, substitute=FALSE, lazy=lazy, globals=globals, local=local, ...)
-  structure(f, class=c("SequentialFuture", class(f)))
+globals.UniprocessFuture <- function(future, ...) {
+  envir <- future$envir
+  globals <- names(envir)
+  if (!"...future_has_globals" %in% globals) return(NULL)
+  globals <- setdiff(globals, "...future_has_globals")
+  mget(globals, envir = envir, inherits = FALSE)
 }
 
 
 #' @rdname UniprocessFuture-class
 #' @export
-EagerFuture <- function(expr=NULL, envir=parent.frame(), substitute=FALSE, lazy=FALSE, globals=TRUE, local=TRUE, ...) {
+SequentialFuture <- function(expr = NULL, envir = parent.frame(), substitute = FALSE, lazy = FALSE, globals = TRUE, local = TRUE, ...) {
   if (substitute) expr <- substitute(expr)
-
-##  .Deprecated(msg = "EagerFuture is deprecated. Instead, use SequentialFuture")
-  
-  f <- UniprocessFuture(expr=expr, envir=envir, substitute=FALSE, lazy=lazy, globals=globals, local=local, ...)
-  structure(f, class=c("EagerFuture", class(f)))
-}
-
-
-#' @rdname UniprocessFuture-class
-#' @export
-LazyFuture <- function(expr=NULL, envir=parent.frame(), substitute=FALSE, lazy=TRUE, globals=TRUE, local=TRUE, ...) {
-  if (substitute) expr <- substitute(expr)
-    
-##  .Deprecated(msg = "LazyFuture is deprecated. Instead, use f <- SequentialFuture(..., lazy = TRUE)")
-    
-  f <- UniprocessFuture(expr=expr, envir=envir, substitute=FALSE, lazy=lazy, globals=globals, local=local, ...)
-  structure(f, class=c("LazyFuture", class(f)))
+  f <- UniprocessFuture(expr = expr, envir = envir, substitute = FALSE, lazy = lazy, globals = globals, local = local, ...)
+  structure(f, class = c("SequentialFuture", class(f)))
 }
