@@ -15,13 +15,13 @@
 #' @example incl/remote.R
 #'
 #' @details
-#' Note that remote futures use \code{persistent=TRUE} by default.
+#' Note that remote futures use \code{persistent = TRUE} by default.
 #'
 #' @export
-remote <- function(expr, envir=parent.frame(), substitute=TRUE, lazy=FALSE, seed=NULL, globals=TRUE, persistent=TRUE, workers=NULL, user=NULL, revtunnel=TRUE, gc=FALSE, earlySignal=FALSE, myip=NULL, label=NULL, ...) {
+remote <- function(expr, envir = parent.frame(), substitute = TRUE, lazy = FALSE, seed = NULL, globals = TRUE, persistent = TRUE, workers = NULL, user = NULL, revtunnel = TRUE, gc = FALSE, earlySignal = FALSE, myip = NULL, label = NULL, ...) {
   if (substitute) expr <- substitute(expr)
 
-  stopifnot(length(workers) >= 1L, is.character(workers), !anyNA(workers))
+  stopifnot(length(workers) >= 1L, !anyNA(workers))
 
   if (is.character(workers)) {
     homogeneous <- FALSE ## Calls plain 'Rscript'
@@ -40,7 +40,7 @@ remote <- function(expr, envir=parent.frame(), substitute=TRUE, lazy=FALSE, seed
       ##     for 'localhost' anyways, but just in case)
       revtunnel <- FALSE
 
-      ## (c) We use myip='127.0.0.1' because it's slightly more
+      ## (c) We use myip = '127.0.0.1' because it's slightly more
       ##     generic than 'localhost'.
       myip <- "127.0.0.1"
     } else {
@@ -64,7 +64,7 @@ remote <- function(expr, envir=parent.frame(), substitute=TRUE, lazy=FALSE, seed
     stop("Argument 'workers' is not of class 'cluster': ", class(workers)[1])
   }
 
-  future <- ClusterFuture(expr=expr, envir=envir, substitute=FALSE, lazy=lazy, seed=seed, globals=globals, persistent=persistent, workers=workers, user=user, master=myip, revtunnel=revtunnel, homogeneous=homogeneous, gc=gc, earlySignal=earlySignal, label=label, ...)
+  future <- ClusterFuture(expr = expr, envir = envir, substitute = FALSE, lazy = lazy, seed = seed, globals = globals, persistent = persistent, workers = workers, user = user, master = myip, revtunnel = revtunnel, homogeneous = homogeneous, gc = gc, earlySignal = earlySignal, label = label, ...)
   if (!future$lazy) future <- run(future)
   invisible(future)
 }
