@@ -6,16 +6,20 @@ message("*** Future class - exception ...")
 
 f <- Future()
 print(f)
-res <- try(value(f), silent=TRUE)
+res <- tryCatch(value(f), error = identity)
 print(res)
-stopifnot(inherits(res, "try-error"))
+stopifnot(inherits(res, "error"))
 
 ## values() is an alias for value() for Future
-res <- try(values(f), silent=TRUE)
-stopifnot(inherits(res, "try-error"))
+res <- tryCatch(values(f), error = identity)
+stopifnot(inherits(res, "error"))
+
+## Invalid seed
+res <- tryCatch(f <- Future(42, seed = 1:2), error = identity)
+stopifnot(inherits(res, "error"))
 
 ## When no packages are exported
-foo <- structure(function(...) { Future(1) }, class="future")
+foo <- structure(function(...) { Future(1) }, class = "future")
 plan(foo)
 f <- Future()
 expr <- getExpression(f)
@@ -24,19 +28,22 @@ stopifnot(is.call(expr))
 
 clazzes <- list(
   sequential = SequentialFuture,
-  multisession = function(...) MultisessionFuture(..., workers=2L),
-  uniprocess = UniprocessFuture,
-  eager = EagerFuture,
-  lazy = LazyFuture
+  multisession = function(...) MultisessionFuture(..., workers = 2L),
+  sequential = SequentialFuture
 )
-if (supportsMulticore()) clazzes$multicore = function(...) MulticoreFuture(..., workers=2L)
+if (supportsMulticore()) {
+  clazzes$multicore = function(...) MulticoreFuture(..., workers = 2L)
+}
+
+## Deprecated class
+clazzes$eager <- EagerFuture
 
 for (clazz in clazzes) {
   ## Calling run() more than once
   f <- clazz({ 42L })
   print(f)
   run(f)
-  res <- tryCatch(run(f), error=identity)
+  res <- tryCatch(run(f), error = identity)
   stopifnot(inherits(res, "error"))
   v <- value(f)
   print(v)
