@@ -2,15 +2,12 @@ source("incl/start.R")
 
 message("*** Futures - labels ...")
 
-strategies <- supportedStrategies()
-strategies <- setdiff(strategies, "multiprocess")
-
-for (strategy in strategies) {
+for (strategy in supportedStrategies()) {
   message(sprintf("- plan('%s') ...", strategy))
   plan(strategy)
 
-  for (label in list(NULL, sprintf("strategy=%s", strategy))) {
-    fcn <- get(strategy, mode="function")
+  for (label in list(NULL, sprintf("strategy = %s", strategy))) {
+    fcn <- get(strategy, mode = "function")
     stopifnot(inherits(fcn, strategy))
     f <- fcn(42, label = label)
     print(f)
